@@ -26,6 +26,7 @@
 #include <libglom/data_structure/layout/layoutitem_field.h>
 #include <glom/glom_privs.h>
 #include <glom/python_embed/glom_python.h>
+#include <glom/application.h>
 #include <algorithm> //For std::find()
 #include <libglom/libglom_config.h>
 #include <glibmm/i18n.h>
@@ -119,7 +120,7 @@ Glib::ustring Box_Data::get_find_where_clause() const
       if(!strClause.empty())
         strClause += "AND ";
 
-      strClause += "(" + strClausePart + ") ";
+      strClause += '(' + strClausePart + ") ";
     }
   }
 
@@ -275,7 +276,7 @@ Document::type_list_layout_groups Box_Data::get_data_layout_groups(const Glib::u
 }
 
 void Box_Data::fill_layout_group_field_info(const sharedptr<LayoutGroup>& group, const Privileges& table_privs)
-{ 
+{
   if(!group)
    return;
 
@@ -350,9 +351,28 @@ Glib::ustring Box_Data::get_layout_name() const
   return m_layout_name;
 }
 
+void Box_Data::on_python_requested_show_table_details(const Glib::ustring& table_name, const Gnome::Gda::Value& primary_key_value)
+{
+  std::cout << "debug: on_python_requested_show_table_details(): " << table_name << ", pk value: " << primary_key_value.to_string() << std::endl;
+  
+  Application* app = Application::get_application();
+  if(app)
+    app->show_table_details(table_name, primary_key_value);
+}
+
+void Box_Data::on_python_requested_show_table_list(const Glib::ustring& table_name)
+{
+  //std::cout << "debug: on_python_requested_show_table_list(): " << table_name << std::endl;
+  
+  Application* app = Application::get_application();
+  if(app)
+    app->show_table_list(table_name);
+}
+  
 void Box_Data::execute_button_script(const sharedptr<const LayoutItem_Button>& layout_item, const Gnome::Gda::Value& primary_key_value)
 {
-  const type_map_fields field_values = get_record_field_values_for_calculation(m_table_name, get_field_primary_key(), primary_key_value);
+  const sharedptr<Field> field_primary_key = get_field_primary_key();
+  const type_map_fields field_values = get_record_field_values_for_calculation(m_table_name, field_primary_key, primary_key_value);
 
   //We need the connection when we run the script, so that the script may use it.
 #ifdef GLIBMM_EXCEPTIONS_ENABLED
@@ -360,12 +380,23 @@ void Box_Data::execute_button_script(const sharedptr<const LayoutItem_Button>& l
 #else
   std::auto_ptr<ExceptionConnection> error;
   sharedptr<SharedConnection> sharedconnection = connect_to_server(0 /* parent window */, error);
-  if(error.get() == NULL)
+  if(!error.get())
   {
 #endif // GLIBMM_EXCEPTIONS_ENABLED
 
-    glom_execute_python_function_implementation(layout_item->get_script(), field_values, //TODO: Maybe use the field's type here.
-      get_document(), get_table_name(), sharedconnection->get_gda_connection());
+    //Allow this UI to respond to UI change requests from the Python code:
+    PythonUICallbacks callbacks;
+    callbacks.signal_show_table_details().connect(
+      sigc::mem_fun(*this, &Box_Data::on_python_requested_show_table_details));
+    callbacks.signal_show_table_list().connect(
+      sigc::mem_fun(*this, &Box_Data::on_python_requested_show_table_list)); 
+          
+    glom_execute_python_function_implementation(layout_item->get_script(),
+      field_values, //TODO: Maybe use the field's type here.
+      get_document(),
+      get_table_name(), field_primary_key, primary_key_value,
+      sharedconnection->get_gda_connection(),
+      callbacks);
 #ifndef GLIBMM_EXCEPTIONS_ENABLED
   }
 #endif // !GLIBMM_EXCEPTIONS_ENABLED
