@@ -25,7 +25,7 @@
 
 #include <glom/box_withbuttons.h>
 #include <glom/base_db_table_data.h>
-#include "dialog_layout.h"
+#include <glom/mode_design/layout/dialog_layout.h>
 
 namespace Glom
 {
@@ -48,7 +48,7 @@ public:
 
   //TODO: Put this in Base_DB_Table_Data?
   ///Create the layout for the database structure, and fill it with data from the database.
-  virtual bool init_db_details(const FoundSet& found_set);
+  virtual bool init_db_details(const FoundSet& found_set, const Glib::ustring& layout_platform);
 
   //Fill the existing layout with data from the database:
   virtual bool refresh_data_from_database_with_where_clause(const FoundSet& found_set);
@@ -68,6 +68,7 @@ public:
 #ifndef GLOM_ENABLE_CLIENT_ONLY
   void show_layout_dialog();
 #endif // !GLOM_ENABLE_CLIENT_ONLY
+
   Glib::ustring get_layout_name() const;
 
   //Signals:
@@ -102,14 +103,18 @@ protected:
 
   /** Get the layout groups, with the Field information filled in.
    */
-  Document_Glom::type_list_layout_groups get_data_layout_groups(const Glib::ustring& layout_name);
+  Document::type_list_layout_groups get_data_layout_groups(const Glib::ustring& layout_name, const Glib::ustring& layout_platform);
   void fill_layout_group_field_info(const sharedptr<LayoutGroup>& group, const Privileges& table_privs);
 
   void execute_button_script(const sharedptr<const LayoutItem_Button>& layout_item, const Gnome::Gda::Value& primary_key_value);
 
   //Signal handlers:
   virtual void on_Button_Find(); //only used by _Find sub-classes. Should be MI.
-
+  
+  //Signal handlers for the PyGlomUI callbacks:
+  void on_python_requested_show_table_details(const Glib::ustring& table_name, const Gnome::Gda::Value& primary_key_value);
+  void on_python_requested_show_table_list(const Glib::ustring& table_name);
+  
   static Glib::ustring xslt_process(const xmlpp::Document& xml_document, const std::string& filepath_xslt);
 
 #ifndef GLOM_ENABLE_CLIENT_ONLY
@@ -125,7 +130,12 @@ protected:
 #ifndef GLOM_ENABLE_CLIENT_ONLY
   Dialog_Layout* m_pDialogLayout;
 #endif // !GLOM_ENABLE_CLIENT_ONLY
+
+  /// "details" or "list", as specified in the Document's XML.
   Glib::ustring m_layout_name;
+
+  /// Empty string or "maemo" as specified in the Document's XML.
+  Glib::ustring m_layout_platform;
 };
 
 } //namespace Glom
