@@ -24,26 +24,26 @@
 #include <gtkmm.h>
 #include "layoutwidgetutils.h"
 #include <libglom/data_structure/layout/layoutitem_button.h>
-#include <libglademm.h>
+#include <gtkmm/builder.h>
 
 namespace Glom
 {
 
-class App_Glom;
+class Application;
 
 class ButtonGlom
 : public Gtk::Button,
   public LayoutWidgetUtils
 {
 public:
-  explicit ButtonGlom(BaseObjectType* cobject, const Glib::RefPtr<Gnome::Glade::Xml>& refGlade);
-  explicit ButtonGlom();
+  explicit ButtonGlom(BaseObjectType* cobject, const Glib::RefPtr<Gtk::Builder>& builder);
+  ButtonGlom();
   virtual ~ButtonGlom();
 
 private:
   void init();
 
-  virtual App_Glom* get_application();
+  virtual Application* get_application();
 #ifndef GLOM_ENABLE_CLIENT_ONLY    
   virtual void on_menu_properties_activate();
   virtual bool on_button_press_event(GdkEventButton *event);
