@@ -18,10 +18,12 @@
  * Boston, MA 02111-1307, USA.
  */
 
+//We include this at the top to use a temporary GTKMM_MAEMO_EXTENSIONS_ENABLED-related fix. 
+#include <glom/application.h> // For get_application().
+
 #include "canvas_image_movable.h"
 #include <goocanvasmm/canvas.h>
 #include <gtkmm/stock.h>
-#include <glom/application.h> // For get_application().
 #include <glom/utility_widgets/imageglom.h> //For ImageGlom::scale_keeping_ratio().
 #include <iostream>
 
@@ -223,7 +225,7 @@ void CanvasImageMovable::set_image_empty()
   Gtk::Widget *widget = get_canvas();
 
   if(!widget)
-    widget = App_Glom::get_application();
+    widget = Application::get_application();
 
   Glib::RefPtr<Gdk::Pixbuf> pixbuf;
   if(widget)
