@@ -26,22 +26,33 @@
 #include <gtkmm.h>
 #include <libglom/data_structure/field.h>
 #include "comboglomchoicesbase.h"
-#include <gtkmm/builder.h>
+
+#ifdef GLOM_ENABLE_MAEMO
+#include <hildonmm/picker-button.h>
+#include <hildonmm/touch-selector-entry.h>
+#endif //GLOM_ENABLE_MAEMO
 
 namespace Glom
 {
 
-class App_Glom;
+class Application;
 
+/** A Gtk::ComboBox that can show choices of field values.
+ * Use this when the user should only be allowed to enter values that are in the choices.
+ */
 class ComboGlom
-: public Gtk::ComboBox,
+: 
+#ifndef GLOM_ENABLE_MAEMO
+  public Gtk::ComboBox,
+#else
+  public Hildon::PickerButton,
+#endif
   public ComboGlomChoicesBase
 {
 public:
-  explicit ComboGlom(BaseObjectType* cobject, const Glib::RefPtr<Gtk::Builder>& builder);
 
   ///You must call set_layout_item() to specify the field type and formatting of the main column.
-  explicit ComboGlom();
+  ComboGlom();
 
   ///You must call set_layout_item() to specify the field type and formatting of the main column.
   explicit ComboGlom(const sharedptr<LayoutItem_Field>& field_second);
@@ -66,9 +77,13 @@ public:
 private:
   void init();
 
-  // Note this is a normal signal handlers when compiled without default
-  // signal handlers
+  #ifndef GLOM_ENABLE_MAEMO
+  // Note that this is a normal signal handler when glibmm was complied
+  // without default signal handlers
   virtual void on_changed(); //From Gtk::ComboBox
+  #else
+  void on_changed(int column);
+  #endif //GLOM_ENABLE_MAEMO
 
   virtual void check_for_change();
 
@@ -76,11 +91,15 @@ private:
   virtual bool on_button_press_event(GdkEventButton *event);
 #endif // !GLOM_ENABLE_CLIENT_ONLY
 
-  virtual App_Glom* get_application();
+  virtual Application* get_application();
 
 
   Glib::ustring m_old_text;
   //Gnome::Gda::Value m_value; //The last-stored value. We have this because the displayed value might be unparseable.
+  
+  #ifdef GLOM_ENABLE_MAEMO
+  Hildon::TouchSelector m_maemo_selector;
+  #endif
 };
 
 } //namespace Glom
